#! /usr/bin/env python3

import codecs
import os.path
from setuptools import setup, find_packages


with open(os.path.join("debian", "changelog"), 'r') as changelog:
    VERSION = changelog.readline().split('(')[1].split('-')[0]

if not VERSION:
    raise Exception("Failed to get version info")

# Always set __version__ to the version found in the changelog to make
# sure the version is always up-to-date  and nobody needs to manually
# update it.
initFilePath = os.path.join('opsidirectoryconnector', '__init__.py')
newInitLines = []
with codecs.open(initFilePath, 'r', 'utf-8') as originalFile:
    for line in originalFile:
        if line.startswith('__version__'):
            newInitLines.append("__version__ = '{0}'\n".format(VERSION))
            continue

        newInitLines.append(line)

with codecs.open(initFilePath, 'w', 'utf-8') as newInitFile:
    newInitFile.writelines(newInitLines)
print("Patched version {1!r} from changelog into {0}".format(initFilePath, VERSION))

setup(
    name="opsi-directory-connector",
    version=VERSION,
    packages=find_packages(),
    # Disabled because of broken pkg_resources on Debian 8 is unable to
    # load ldap3.
    # entry_points={
    #     'console_scripts': [
    #         'opsidirectoryconnector = opsidirectoryconnector:runConnector',
    #     ]
    # },
    scripts=['scripts/opsidirectoryconnector'],

    install_requires=['ldap3', 'requests'],

    data_files=[
        ('/etc/opsi', ['data/etc/opsi/opsidirectoryconnector.example.conf']),
    ],

    # metadata for upload to PyPI
    author="uib GmbH",
    author_email="info@uib.de",
    description="opsi directory connector",
    url="http://uib.de/",   # project home page, if any
)
